@@ -1,5 +1,9 @@
 #pragma once
 
+/// @file
+/// @brief A header including pretty much all the headers of the library.
+/// Including this will have a significant compile time cost.
+
 #include "mtx/identifiers.hpp"
 
 #include "mtx/events.hpp"
@@ -17,8 +21,10 @@
 #include "mtx/events/redaction.hpp"
 #include "mtx/events/tag.hpp"
 #include "mtx/events/topic.hpp"
+#include "mtx/events/voip.hpp"
 
 #include "mtx/events/messages/audio.hpp"
+#include "mtx/events/messages/confetti.hpp"
 #include "mtx/events/messages/emote.hpp"
 #include "mtx/events/messages/file.hpp"
 #include "mtx/events/messages/image.hpp"
@@ -26,5 +32,7 @@
 #include "mtx/events/messages/text.hpp"
 #include "mtx/events/messages/video.hpp"
 
+#include "mtx/user_interactive.hpp"
+
 #include "mtx/requests.hpp"
 #include "mtx/responses.hpp"
