@@ -39,6 +39,7 @@
 #include "mtx/pushrules.hpp"
 
 #include "mtx/events/messages/audio.hpp"
+#include "mtx/events/messages/confetti.hpp"
 #include "mtx/events/messages/emote.hpp"
 #include "mtx/events/messages/file.hpp"
 #include "mtx/events/messages/image.hpp"
@@ -165,6 +166,7 @@ using TimelineEvents =
                mtx::events::RoomEvent<mtx::events::msg::Reaction>,
                mtx::events::RoomEvent<mtx::events::msg::Redacted>,
                mtx::events::RoomEvent<mtx::events::msg::Audio>,
+               mtx::events::RoomEvent<mtx::events::msg::Confetti>,
                mtx::events::RoomEvent<mtx::events::msg::Emote>,
                mtx::events::RoomEvent<mtx::events::msg::File>,
                mtx::events::RoomEvent<mtx::events::msg::Image>,
@@ -197,10 +199,10 @@ using EphemeralEvents = std::variant<mtx::events::EphemeralEvent<mtx::events::ep
 struct TimelineEvent
 {
     TimelineEvents data;
-};
 
-void
-from_json(const nlohmann::json &obj, TimelineEvent &e);
+    friend void from_json(const nlohmann::json &obj, TimelineEvent &e);
+    friend void to_json(nlohmann::json &obj, const TimelineEvent &e);
+};
 
 } // namespace collections
 
@@ -234,6 +236,9 @@ template<>
 constexpr inline EventType message_content_to_type<mtx::events::msg::Video> =
   EventType::RoomMessage;
 template<>
+constexpr inline EventType message_content_to_type<mtx::events::msg::Confetti> =
+  EventType::RoomMessage;
+template<>
 constexpr inline EventType message_content_to_type<mtx::events::msg::StickerImage> =
   EventType::Sticker;
 template<>
