@@ -18,6 +18,7 @@
 namespace mtx {
 namespace responses {
 
+//! Information about one of your devices.
 struct Device
 {
     //! **Required.** Identifier of this device.
@@ -33,10 +34,9 @@ struct Device
     //! The timestamp (in milliseconds since the unix epoch) when this devices was last seen. (May
     //! be a few minutes out of date, for efficiency reasons).
     size_t last_seen_ts;
-};
 
-void
-from_json(const nlohmann::json &obj, Device &res);
+    friend void from_json(const nlohmann::json &obj, Device &res);
+};
 
 //! Response from the `GET /_matrix/client/r0/devices` endpoint.
 struct QueryDevices
@@ -45,10 +45,9 @@ struct QueryDevices
     //! A list of all registered devices for this user.
     //
     std::vector<Device> devices;
+
+    friend void from_json(const nlohmann::json &obj, QueryDevices &response);
 };
 
-void
-from_json(const nlohmann::json &obj, QueryDevices &response);
-
 }
 }
