@@ -14,15 +14,17 @@
 namespace mtx {
 namespace responses {
 
-// Used to represent empty responses
+//! Used to represent empty responses
 struct Empty
-{};
+{
+    friend void from_json(const nlohmann::json &, Empty &);
+};
 
-void
-from_json(const nlohmann::json &, Empty &);
-
-using Logout      = Empty;
+//! The response for a logout.
+using Logout = Empty;
+//! The response after changing your display name.
 using DisplayName = Empty;
-using RoomInvite  = Empty;
+//! The response after inviting a user to a room.
+using RoomInvite = Empty;
 }
 }
