@@ -12,6 +12,7 @@
 #include <olm/pk.h>
 
 #include <algorithm>
+#include <cstdint>
 
 #include "mtx/log.hpp"
 #include "mtxclient/crypto/client.hpp"
@@ -215,8 +216,9 @@ compatible_iv(BinaryBuf incompatible_iv)
     // the last byte. So we need to clear byte 15 - 63%8 = 15 - 7 = 8, the highest bit, 1 << 7
     // see:
     // https://github.com/matrix-org/matrix-js-sdk/blob/529fe93ab14b93c515e9ab0d0277c1942a5d73c5/src/crypto/aes.ts#L144
-    uint8_t *data = incompatible_iv.data();
-    data[15 - 63 % 8] &= ~(1UL << (63 / 8));
+    uint8_t *data               = incompatible_iv.data();
+    constexpr std::uint8_t mask = static_cast<std::uint8_t>(~(1U << (63 / 8)));
+    data[15 - 63 % 8] &= mask;
     return incompatible_iv;
 }
 
@@ -233,7 +235,7 @@ AES_CTR_256_Encrypt(const std::string &plaintext, const BinaryBuf &aes256Key, Bi
     BinaryBuf encrypted = compatible_iv(create_buffer(plaintext.size() + AES_BLOCK_SIZE));
 
     /* Create and initialise the context */
-    if (!(ctx = EVP_CIPHER_CTX_new())) {
+    if (ctx = EVP_CIPHER_CTX_new(); !ctx) {
         // handleErrors();
     }
 
@@ -281,7 +283,7 @@ AES_CTR_256_Decrypt(const std::string &ciphertext, const BinaryBuf &aes256Key, B
     BinaryBuf decrypted = create_buffer(ciphertext.size());
 
     /* Create and initialise the context */
-    if (!(ctx = EVP_CIPHER_CTX_new())) {
+    if (ctx = EVP_CIPHER_CTX_new(); !ctx) {
         // handleErrors();
     }
 
@@ -489,12 +491,13 @@ encrypt_file(const std::string &plaintext)
     mtx::crypto::EncryptedFile encryption_info;
 
     // iv has to be 16 bytes, key 32!
-    BinaryBuf key = create_buffer(32);
-    BinaryBuf iv  = create_buffer(16);
-    iv[15 - 63 % 8] &= ~(1UL << (63 / 8));
+    BinaryBuf key               = create_buffer(32);
+    BinaryBuf iv                = create_buffer(16);
+    constexpr std::uint8_t mask = static_cast<std::uint8_t>(~(1U << (63 / 8)));
+    iv[15 - 63 % 8] &= mask;
 
     // Counter should be 0 in v1.1 of the spec...
-    for (int i = 8; i < 16; i++)
+    for (std::size_t i = 8; i < 16; i++)
         iv[i] = 0;
 
     BinaryBuf cyphertext = AES_CTR_256_Encrypt(plaintext, key, iv);
@@ -553,7 +556,8 @@ HMAC_SHA256(const BinaryBuf &hmacKey, const BinaryBuf &data)
 void
 uint8_to_uint32(uint8_t b[4], uint32_t &u32)
 {
-    u32 = b[0] << 24 | b[1] << 16 | b[2] << 8 | b[3];
+    u32 = std::uint32_t{b[0]} << 24 | std::uint32_t{b[1]} << 16 | std::uint32_t{b[2]} << 8 |
+          std::uint32_t{b[3]};
 }
 
 void
