@@ -41,6 +41,7 @@ MTXCLIENT_INSTANTIATE_JSON_FUNCTIONS(events::RoomEvent, mtx::events::msg::Sticke
 MTXCLIENT_INSTANTIATE_JSON_FUNCTIONS(events::RoomEvent, mtx::events::msg::Reaction)
 MTXCLIENT_INSTANTIATE_JSON_FUNCTIONS(events::RoomEvent, mtx::events::msg::Redacted)
 MTXCLIENT_INSTANTIATE_JSON_FUNCTIONS(events::RoomEvent, mtx::events::msg::Audio)
+MTXCLIENT_INSTANTIATE_JSON_FUNCTIONS(events::RoomEvent, mtx::events::msg::Confetti)
 MTXCLIENT_INSTANTIATE_JSON_FUNCTIONS(events::RoomEvent, mtx::events::msg::Emote)
 MTXCLIENT_INSTANTIATE_JSON_FUNCTIONS(events::RoomEvent, mtx::events::msg::File)
 MTXCLIENT_INSTANTIATE_JSON_FUNCTIONS(events::RoomEvent, mtx::events::msg::Image)
@@ -126,6 +127,12 @@ MTXCLIENT_INSTANTIATE_JSON_FUNCTIONS(events::RedactionEvent, msg::Redaction)
 }
 
 namespace mtx::events::collections {
+void
+to_json(nlohmann::json &obj, const TimelineEvent &e)
+{
+    std::visit([&obj](const auto &ev) { return to_json(obj, ev); }, e.data);
+}
+
 void
 from_json(const nlohmann::json &obj, TimelineEvent &e)
 {
@@ -285,6 +292,10 @@ from_json(const nlohmann::json &obj, TimelineEvent &e)
                 e.data = events::RoomEvent<events::msg::Audio>(obj);
                 break;
             }
+            case MsgType::Confetti: {
+                e.data = events::RoomEvent<events::msg::Confetti>(obj);
+                break;
+            }
             case MsgType::Emote: {
                 e.data = events::RoomEvent<events::msg::Emote>(obj);
                 break;
