@@ -47,11 +47,10 @@ from_json(const json &obj, Create &create)
 void
 to_json(json &obj, const Create &create)
 {
-    obj["creator"]    = create.creator;
+    if (!create.creator.empty())
+        obj["creator"] = create.creator;
     obj["m.federate"] = create.federate;
-    if (create.room_version.empty())
-        obj["room_version"] = "1";
-    else
+    if (!create.room_version.empty())
         obj["room_version"] = create.room_version;
 
     if (create.type)
