@@ -198,7 +198,7 @@ parse_room_account_data_events(
             case events::EventType::ImagePackInRoom:
                 continue;
             }
-        } catch (json::exception &err) {
+        } catch (std::exception &err) {
             log_error(err, e);
         }
     }
@@ -389,6 +389,11 @@ parse_timeline_events(const json &events,
 
                     break;
                 }
+                case MsgType::Confetti: {
+                    container.emplace_back(events::RoomEvent<events::msg::Confetti>(e));
+
+                    break;
+                }
                 case MsgType::Emote: {
                     container.emplace_back(events::RoomEvent<events::msg::Emote>(e));
 
@@ -506,7 +511,7 @@ parse_timeline_events(const json &events,
             case events::EventType::Dummy:
                 continue;
             }
-        } catch (json::exception &err) {
+        } catch (std::exception &err) {
             log_error(err, e);
         }
     }
@@ -604,7 +609,7 @@ parse_device_events(const json &events,
             default:
                 continue;
             }
-        } catch (json::exception &err) {
+        } catch (std::exception &err) {
             log_error(err, e);
         }
     }
@@ -779,7 +784,7 @@ parse_state_events(const json &events,
             case events::EventType::Dummy:
                 continue;
             }
-        } catch (json::exception &err) {
+        } catch (std::exception &err) {
             log_error(err, e);
         }
     }
@@ -942,7 +947,7 @@ parse_stripped_events(const json &events,
             case events::EventType::Dummy:
                 continue;
             }
-        } catch (json::exception &err) {
+        } catch (std::exception &err) {
             log_error(err, e);
         }
     }
@@ -976,7 +981,7 @@ parse_ephemeral_events(const json &events,
             default:
                 continue;
             }
-        } catch (json::exception &err) {
+        } catch (std::exception &err) {
             utils::log_error(err, e);
         }
     }
