@@ -48,8 +48,8 @@ from_json(const nlohmann::json &obj, OlmMessage &msg)
     if (obj.at("content").at("algorithm") != OLM_ALGO)
         throw std::invalid_argument("invalid algorithm for olm message");
 
-    msg.sender     = obj.at("sender");
-    msg.sender_key = obj.at("content").at("sender_key");
+    msg.sender     = obj.at("sender").get<std::string>();
+    msg.sender_key = obj.at("content").at("sender_key").get<std::string>();
     msg.ciphertext =
       obj.at("content").at("ciphertext").get<std::map<std::string, OlmCipherContent>>();
 }
@@ -61,7 +61,7 @@ generate_keys(std::shared_ptr<mtx::crypto::OlmClient> account)
     account->generate_one_time_keys(1);
     auto otks = account->one_time_keys();
 
-    return account->create_upload_keys_request(otks);
+    return account->create_upload_keys_request(otks, {});
 }
 
 TEST(Encryption, UploadIdentityKeys)
@@ -88,7 +88,7 @@ TEST(Encryption, UploadIdentityKeys)
     ASSERT_TRUE(id_keys.curve25519.size() > 10);
 
     mtx::crypto::OneTimeKeys unused;
-    auto request = olm_account->create_upload_keys_request(unused);
+    auto request = olm_account->create_upload_keys_request(unused, {});
 
     // Make the request with the signed identity keys.
     alice->upload_keys(request, [](const mtx::responses::UploadKeys &res, RequestErr err) {
@@ -115,20 +115,16 @@ TEST(Encryption, UploadOneTimeKeys)
     olm_account->set_user_id(alice->user_id().to_string());
     olm_account->set_device_id(alice->device_id());
 
-    auto nkeys = olm_account->generate_one_time_keys(5);
+    auto nkeys = olm_account->generate_one_time_keys(5, true);
     EXPECT_EQ(nkeys, 5);
 
-    auto otks = olm_account->one_time_keys();
-
-    mtx::requests::UploadKeys req;
-
-    for (auto [key_id, key] : otks.curve25519)
-        req.one_time_keys["curve25519:" + key_id] = key;
+    mtx::requests::UploadKeys req = olm_account->create_upload_keys_request();
 
     alice->upload_keys(req, [](const mtx::responses::UploadKeys &res, RequestErr err) {
         check_error(err);
-        ASSERT_TRUE(res.one_time_key_counts.find("curve25519") != res.one_time_key_counts.end());
-        EXPECT_EQ(res.one_time_key_counts.at("curve25519"), 5);
+        ASSERT_TRUE(res.one_time_key_counts.find("signed_curve25519") !=
+                    res.one_time_key_counts.end());
+        EXPECT_EQ(res.one_time_key_counts.at("signed_curve25519"), 5);
     });
 
     alice->close();
@@ -356,8 +352,9 @@ TEST(Encryption, ClaimKeys)
           const auto current_device = bob_devices.at(bob->device_id());
 
           // Verify signature.
-          ASSERT_TRUE(verify_identity_signature(
-            json(current_device), DeviceId(bob->device_id()), UserId(bob->user_id().to_string())));
+          ASSERT_TRUE(verify_identity_signature(json(current_device).get<mtx::crypto::DeviceKeys>(),
+                                                DeviceId(bob->device_id()),
+                                                UserId(bob->user_id().to_string())));
 
           mtx::requests::ClaimKeys claim_keys;
           for (const auto &d : devices)
@@ -488,7 +485,7 @@ TEST(Encryption, UploadCrossSigningKeys)
     ASSERT_TRUE(id_keys.curve25519.size() > 10);
 
     mtx::crypto::OneTimeKeys unused;
-    auto request = olm_account->create_upload_keys_request(unused);
+    auto request = olm_account->create_upload_keys_request(unused, {});
 
     // Make the request with the signed identity keys.
     alice->upload_keys(
@@ -546,7 +543,7 @@ TEST(Encryption, UploadOnlineBackup)
     ASSERT_TRUE(id_keys.curve25519.size() > 10);
 
     mtx::crypto::OneTimeKeys unused;
-    auto request = olm_account->create_upload_keys_request(unused);
+    auto request = olm_account->create_upload_keys_request(unused, {});
 
     // Make the request with the signed identity keys.
     alice->upload_keys(
@@ -717,8 +714,10 @@ TEST(Encryption, CreateOutboundGroupSession)
 
     auto outbound_session = alice->init_outbound_group_session();
 
-    auto session_id  = mtx::crypto::session_id(outbound_session.get());
+    auto session_id = mtx::crypto::session_id(outbound_session.get());
+    ASSERT_FALSE(session_id.empty());
     auto session_key = mtx::crypto::session_key(outbound_session.get());
+    ASSERT_FALSE(session_key.empty());
 }
 
 TEST(Encryption, OlmSessions)
@@ -932,7 +931,8 @@ TEST(Encryption, OlmRoomKeyEncryption)
                                auto retrieved_devices = res.one_time_keys.at(user_id);
                                for (const auto &device : retrieved_devices) {
                                    if (device.first == device_id) {
-                                       bob_otk = device.second.begin()->at("key");
+                                       bob_otk =
+                                         device.second.begin()->at("key").get<std::string>();
                                        break;
                                    }
                                }
@@ -979,8 +979,9 @@ TEST(Encryption, OlmRoomKeyEncryption)
 
           EXPECT_EQ(res.to_device.events.size(), 1);
 
-          auto olm_msg = std::get<DeviceEvent<msgs::OlmEncrypted>>(res.to_device.events[0]).content;
-          auto cipher  = olm_msg.ciphertext.begin();
+          auto olm_msg =
+            std::get<DeviceEvent<mtx::events::msg::OlmEncrypted>>(res.to_device.events[0]).content;
+          auto cipher = olm_msg.ciphertext.begin();
 
           EXPECT_EQ(cipher->first, bob->identity_keys().curve25519);
 
@@ -997,7 +998,7 @@ TEST(Encryption, OlmRoomKeyEncryption)
 
           // Parsing the original plaintext json object.
           auto plaintext     = json::parse(std::string((char *)output.data(), output.size()));
-          std::string secret = plaintext.at("content").at("secret");
+          std::string secret = plaintext.at("content").at("secret").get<std::string>();
 
           ASSERT_EQ(secret, SECRET_TEXT);
       });
@@ -1087,7 +1088,8 @@ TEST(Encryption, ShareSecret)
                                auto retrieved_devices = res.one_time_keys.at(user_id);
                                for (const auto &device : retrieved_devices) {
                                    if (device.first == device_id) {
-                                       bob_otk = device.second.begin()->at("key");
+                                       bob_otk =
+                                         device.second.begin()->at("key").get<std::string>();
                                        break;
                                    }
                                }
@@ -1146,7 +1148,8 @@ TEST(Encryption, ShareSecret)
 
               std::map<mtx::identifiers::User,
                        std::map<std::string, mtx::events::msg::OlmEncrypted>>
-                body{{bob_http->user_id(), {{bob_http->device_id(), device_msg}}}};
+                body{{bob_http->user_id(),
+                      {{bob_http->device_id(), device_msg.get<mtx::events::msg::OlmEncrypted>()}}}};
               alice_http->send_to_device<OlmEncrypted>(
                 alice_http->generate_txn_id(), body, [&is_sent](RequestErr err) {
                     check_error(err);
@@ -1164,8 +1167,9 @@ TEST(Encryption, ShareSecret)
 
           EXPECT_EQ(res.to_device.events.size(), 1);
 
-          auto olm_msg = std::get<DeviceEvent<msgs::OlmEncrypted>>(res.to_device.events[0]).content;
-          auto cipher  = olm_msg.ciphertext.begin();
+          auto olm_msg =
+            std::get<DeviceEvent<mtx::events::msg::OlmEncrypted>>(res.to_device.events[0]).content;
+          auto cipher = olm_msg.ciphertext.begin();
 
           EXPECT_EQ(cipher->first, bob->identity_keys().curve25519);
 
@@ -1401,7 +1405,7 @@ TEST(Encryption, EncryptedFile)
     // IV needs to be 16 bytes/128 bits
     ASSERT_EQ(16, mtx::crypto::base642bin_unpadded(encryption_data.second.iv).size());
 
-    json j                                            = R"({
+    json j = R"({
   "type": "m.room.message",
   "content": {
     "body": "test.txt",
@@ -1439,7 +1443,8 @@ TEST(Encryption, EncryptedFile)
   },
   "room_id": "!YnUlhwgbBaGcAFsJOJ:neko.dev"
 })"_json;
-    mtx::events::RoomEvent<mtx::events::msg::File> ev = j;
+    mtx::events::RoomEvent<mtx::events::msg::File> ev =
+      j.get<mtx::events::RoomEvent<mtx::events::msg::File>>();
 
     ASSERT_EQ("abcdefg\n",
               mtx::crypto::to_string(
