@@ -334,6 +334,32 @@ TEST(StateEvents, CreateWithType)
 
     EXPECT_TRUE(event.content.type.has_value());
     EXPECT_EQ(event.content.type.value(), ns::state::room_type::space);
+
+    json room_v10 = R"(
+{
+  "content": {
+    "creator": "@test:neko.dev",
+    "predecessor": {
+      "event_id": "$hpB30pm_PDHq9dcz7zJR6gwnEFRPxzea7J8bxVuuSTg",
+      "room_id": "!isYaZDvAOnwGmoNKgD:neko.dev"
+    },
+    "room_version": "10"
+  },
+  "origin_server_ts": 1670903493618,
+  "sender": "@test:neko.dev",
+  "state_key": "",
+  "type": "m.room.create",
+  "unsigned": {
+    "age": 118
+  },
+  "event_id": "$2NH68IAcuHuAwsy1WEyLqAnOH_iAVjyUu2GP5IksnYc",
+  "room_id": "!FhwxBVrewHNqikGaXN:neko.dev"
+}
+    )"_json;
+
+    event = room_v10.get<ns::StateEvent<ns::state::Create>>();
+
+    EXPECT_EQ(event.content.room_version, "10");
 }
 
 TEST(StateEvents, GuestAccess)
@@ -1257,7 +1283,8 @@ TEST(StateEvents, ImagePack)
     EXPECT_EQ(event.origin_server_ts, 1510476064445);
     EXPECT_EQ(event.unsigned_data.age, 37);
     EXPECT_EQ(event.state_key, "my-pack");
-    EXPECT_EQ(event.content.pack.has_value(), true);
+    ASSERT_EQ(event.content.pack.has_value(), true);
+    assert(event.content.pack);
     EXPECT_EQ(event.content.pack->display_name, "Awesome Pack");
     EXPECT_EQ(event.content.pack->attribution, "huh");
     EXPECT_EQ(event.content.pack->avatar_url, "mxc://example.org/asdjfasd");
@@ -1272,6 +1299,22 @@ TEST(StateEvents, ImagePack)
     EXPECT_EQ(event.content.images["sticker"].is_emoji(), false);
     EXPECT_EQ(event.content.images["sticker"].overrides_usage(), true);
     EXPECT_EQ(json(event)["content"]["images"].size(), 2);
+
+    json data2 = R"({
+          "origin_server_ts": 1510476064445,
+          "sender": "@nheko_test:matrix.org",
+          "event_id": "$15104760642668662QICBu:matrix.org",
+          "unsigned": {
+            "age": 37
+          },
+          "state_key": "my-pack",
+          "content": {
+},
+          "type": "im.ponies.room_emotes",
+          "room_id": "!lfoDRlNFWlvOnvkBwQ:matrix.org"
+        })"_json;
+
+    EXPECT_NO_THROW(data2.get<ns::StateEvent<ns::msc2545::ImagePack>>());
 }
 
 TEST(StateEvents, Widget)
@@ -1539,8 +1582,8 @@ TEST(ToDevice, KeyVerificationRequest)
     "type": "m.key.verification.request"
 })"_json;
 
-    ns::Event<ns::msg::KeyVerificationRequest> event =
-      request_data.get<ns::Event<ns::msg::KeyVerificationRequest>>();
+    ns::DeviceEvent<ns::msg::KeyVerificationRequest> event =
+      request_data.get<ns::DeviceEvent<ns::msg::KeyVerificationRequest>>();
     auto keyEvent = event.content;
     EXPECT_EQ(keyEvent.from_device, "AliceDevice2");
     EXPECT_EQ(event.type, mtx::events::EventType::KeyVerificationRequest);
@@ -1576,8 +1619,8 @@ TEST(ToDevice, KeyVerificationStart)
     "type": "m.key.verification.start"
 })"_json;
 
-    ns::Event<ns::msg::KeyVerificationStart> event =
-      request_data.get<ns::Event<ns::msg::KeyVerificationStart>>();
+    ns::DeviceEvent<ns::msg::KeyVerificationStart> event =
+      request_data.get<ns::DeviceEvent<ns::msg::KeyVerificationStart>>();
     auto keyEvent = event.content;
     EXPECT_EQ(keyEvent.from_device, "BobDevice1");
     EXPECT_EQ(keyEvent.hashes[0], "sha256");
@@ -1612,8 +1655,8 @@ TEST(ToDevice, KeyVerificationAccept)
     "type": "m.key.verification.accept"
 })"_json;
 
-    ns::Event<ns::msg::KeyVerificationAccept> event =
-      request_data.get<ns::Event<ns::msg::KeyVerificationAccept>>();
+    ns::DeviceEvent<ns::msg::KeyVerificationAccept> event =
+      request_data.get<ns::DeviceEvent<ns::msg::KeyVerificationAccept>>();
     auto keyEvent = event.content;
     EXPECT_EQ(event.type, mtx::events::EventType::KeyVerificationAccept);
     EXPECT_EQ(
@@ -1640,8 +1683,8 @@ TEST(ToDevice, KeyVerificationReady)
     "type": "m.key.verification.ready"
 })"_json;
 
-    ns::Event<ns::msg::KeyVerificationReady> event =
-      request_data.get<ns::Event<ns::msg::KeyVerificationReady>>();
+    ns::DeviceEvent<ns::msg::KeyVerificationReady> event =
+      request_data.get<ns::DeviceEvent<ns::msg::KeyVerificationReady>>();
     auto keyEvent = event.content;
     EXPECT_EQ(event.sender, "test_user");
     EXPECT_EQ(event.type, mtx::events::EventType::KeyVerificationReady);
@@ -1660,8 +1703,8 @@ TEST(ToDevice, KeyVerificationDone)
     "type": "m.key.verification.done"
 })"_json;
 
-    ns::Event<ns::msg::KeyVerificationDone> event =
-      request_data.get<ns::Event<ns::msg::KeyVerificationDone>>();
+    ns::DeviceEvent<ns::msg::KeyVerificationDone> event =
+      request_data.get<ns::DeviceEvent<ns::msg::KeyVerificationDone>>();
     auto keyEvent = event.content;
     EXPECT_EQ(event.sender, "test_user");
     EXPECT_EQ(event.type, mtx::events::EventType::KeyVerificationDone);
@@ -1680,8 +1723,8 @@ TEST(ToDevice, KeyVerificationCancel)
     "type": "m.key.verification.cancel"
 })"_json;
 
-    ns::Event<ns::msg::KeyVerificationCancel> event =
-      request_data.get<ns::Event<ns::msg::KeyVerificationCancel>>();
+    ns::DeviceEvent<ns::msg::KeyVerificationCancel> event =
+      request_data.get<ns::DeviceEvent<ns::msg::KeyVerificationCancel>>();
     auto keyEvent = event.content;
     EXPECT_EQ(event.type, mtx::events::EventType::KeyVerificationCancel);
     EXPECT_EQ(keyEvent.code, "m.user");
@@ -1701,8 +1744,8 @@ TEST(ToDevice, KeyVerificationKey)
     "type": "m.key.verification.key"
 })"_json;
 
-    ns::Event<ns::msg::KeyVerificationKey> event =
-      request_data.get<ns::Event<ns::msg::KeyVerificationKey>>();
+    ns::DeviceEvent<ns::msg::KeyVerificationKey> event =
+      request_data.get<ns::DeviceEvent<ns::msg::KeyVerificationKey>>();
     auto keyEvent = event.content;
     EXPECT_EQ(event.type, mtx::events::EventType::KeyVerificationKey);
     EXPECT_EQ(
@@ -1726,8 +1769,8 @@ TEST(ToDevice, KeyVerificationMac)
     "type": "m.key.verification.mac"
 })"_json;
 
-    ns::Event<ns::msg::KeyVerificationMac> event =
-      request_data.get<ns::Event<ns::msg::KeyVerificationMac>>();
+    ns::DeviceEvent<ns::msg::KeyVerificationMac> event =
+      request_data.get<ns::DeviceEvent<ns::msg::KeyVerificationMac>>();
     auto keyEvent = event.content;
     EXPECT_EQ(event.type, mtx::events::EventType::KeyVerificationMac);
     EXPECT_EQ(
